@@ -155,6 +155,7 @@ void ConfigurationDialog::item_icon_size_changed(GtkComboBox* combo)
 void ConfigurationDialog::style_changed(GtkComboBox* combo)
 {
 	m_plugin->set_button_style(Plugin::ButtonStyle(gtk_combo_box_get_active(combo) + 1));
+	gtk_widget_set_sensitive(m_button_single_row, gtk_combo_box_get_active(combo) == 0);
 }
 
 //-----------------------------------------------------------------------------
@@ -167,6 +168,14 @@ void ConfigurationDialog::title_changed(GtkEditable* editable)
 
 //-----------------------------------------------------------------------------
 
+void ConfigurationDialog::toggle_button_single_row(GtkToggleButton* button)
+{
+	wm_settings->button_single_row = gtk_toggle_button_get_active(button);
+	m_plugin->set_button_style(Plugin::ButtonStyle(gtk_combo_box_get_active(GTK_COMBO_BOX(m_button_style)) + 1));
+}
+
+//-----------------------------------------------------------------------------
+
 void ConfigurationDialog::toggle_hover_switch_category(GtkToggleButton* button)
 {
 	wm_settings->category_hover_activate = gtk_toggle_button_get_active(button);
@@ -220,6 +229,14 @@ void ConfigurationDialog::toggle_position_commands_alternate(GtkToggleButton* bu
 
 //-----------------------------------------------------------------------------
 
+void ConfigurationDialog::toggle_position_categories_alternate(GtkToggleButton* button)
+{
+	wm_settings->position_categories_alternate = gtk_toggle_button_get_active(button);
+	wm_settings->set_modified();
+}
+
+//-----------------------------------------------------------------------------
+
 void ConfigurationDialog::toggle_remember_favorites(GtkToggleButton* button)
 {
 	wm_settings->favorites_in_recent = gtk_toggle_button_get_active(button);
@@ -498,6 +515,12 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 	xfce_panel_image_set_size(XFCE_PANEL_IMAGE(m_icon), 48);
 	gtk_container_add(GTK_CONTAINER(m_icon_button), m_icon);
 
+	m_button_single_row = gtk_check_button_new_with_mnemonic(_("Lay out icon in a single _panel row"));
+	gtk_box_pack_start(panel_vbox, m_button_single_row, true, true, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_button_single_row), wm_settings->button_single_row);
+	gtk_widget_set_sensitive(m_button_single_row, gtk_combo_box_get_active(GTK_COMBO_BOX (m_button_style)) == 0);
+	g_signal_connect_slot(m_button_single_row, "toggled", &ConfigurationDialog::toggle_button_single_row, this);
+
 	// Create menu section
 	label_size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 	GtkBox* appearance_vbox = GTK_BOX(gtk_vbox_new(false, 6));
@@ -536,6 +559,12 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 	gtk_widget_set_sensitive(GTK_WIDGET(m_position_commands_alternate), wm_settings->position_commands_alternate);
 	g_signal_connect_slot(m_position_commands_alternate, "toggled", &ConfigurationDialog::toggle_position_commands_alternate, this);
 
+	// Add option to use alternate categories position
+	m_position_categories_alternate = gtk_check_button_new_with_mnemonic(_("Position cate_gories next to panel button"));
+	gtk_box_pack_start(appearance_vbox, m_position_categories_alternate, true, true, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_position_categories_alternate), wm_settings->position_categories_alternate);
+	g_signal_connect_slot(m_position_categories_alternate, "toggled", &ConfigurationDialog::toggle_position_categories_alternate, this);
+
 	// Add item icon size selector
 	hbox = GTK_BOX(gtk_hbox_new(false, 12));
 	gtk_box_pack_start(appearance_vbox, GTK_WIDGET(hbox), false, false, 0);
