@@ -59,6 +59,7 @@ Window::Window() :
 	gtk_window_set_decorated(m_window, false);
 	gtk_window_set_skip_taskbar_hint(m_window, true);
 	gtk_window_set_skip_pager_hint(m_window, true);
+	gtk_window_set_type_hint(m_window, GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_window_stick(m_window);
 	gtk_widget_add_events(GTK_WIDGET(m_window), GDK_BUTTON_PRESS_MASK | GDK_LEAVE_NOTIFY_MASK | GDK_STRUCTURE_MASK);
 	g_signal_connect_slot(m_window, "enter-notify-event", &Window::on_enter_notify_event, this);
@@ -99,6 +100,7 @@ Window::Window() :
 	m_username = GTK_LABEL(gtk_label_new(NULL));
 	gtk_label_set_markup(m_username, username);
 	gtk_misc_set_alignment(GTK_MISC(m_username), 0.0f, 0.5f);
+	gtk_misc_set_padding(GTK_MISC(m_username), 10, 0);
 	g_free(username);
 
 	// Create action buttons
@@ -217,11 +219,16 @@ Window::Window() :
 	gtk_widget_hide(m_search_results->get_widget());
 	m_default_button->set_active(true);
 	gtk_widget_hide(m_window_contents);
+	gtk_widget_show(m_window_load_contents);
 
 	// Resize to last known size
 	gtk_window_set_default_size(m_window, m_geometry.width, m_geometry.height);
 
 	g_object_ref_sink(m_window);
+
+	// Start loading applications immediately
+	m_applications->load_applications();
+	gtk_spinner_start(m_window_load_spinner);
 }
 
 //-----------------------------------------------------------------------------
@@ -274,7 +281,7 @@ void Window::show(GtkWidget* parent, bool horizontal)
 	}
 
 	// Make sure applications list is current; does nothing unless list has changed
-	if (m_applications->load_applications())
+	if (m_applications->load_applications() && gtk_widget_get_visible(m_window_contents))
 	{
 		gtk_widget_hide(m_window_contents);
 		gtk_widget_show(m_window_load_contents);
@@ -435,6 +442,17 @@ void Window::show(GtkWidget* parent, bool horizontal)
 			g_object_unref(m_commands_align);
 		}
 	}
+	if ((layout_left && !wm_settings->position_categories_alternate)
+			|| (!layout_left && wm_settings->position_categories_alternate))
+	{
+		gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_panels_box), 1);
+		gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_sidebar), 2);
+	}
+	else
+	{
+		gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_panels_box), 2);
+		gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_sidebar), 1);
+	}
 	if (layout_left != m_layout_left)
 	{
 		m_layout_left = layout_left;
@@ -453,9 +471,6 @@ void Window::show(GtkWidget* parent, bool horizontal)
 
 			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_search_entry), 0);
 			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_commands_align), 1);
-
-			gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_panels_box), 1);
-			gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_sidebar), 2);
 		}
 		else if (m_layout_commands_alternate)
 		{
@@ -472,9 +487,6 @@ void Window::show(GtkWidget* parent, bool horizontal)
 
 			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_search_entry), 1);
 			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_commands_align), 0);
-
-			gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_panels_box), 2);
-			gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_sidebar), 1);
 		}
 		else if (m_layout_left)
 		{
@@ -489,9 +501,6 @@ void Window::show(GtkWidget* parent, bool horizontal)
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_username), 0);
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_commands_align), 1);
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_resizer->get_widget()), 2);
-
-			gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_panels_box), 1);
-			gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_sidebar), 2);
 		}
 		else
 		{
@@ -506,9 +515,6 @@ void Window::show(GtkWidget* parent, bool horizontal)
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_username), 2);
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_commands_align), 1);
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_resizer->get_widget()), 0);
-
-			gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_panels_box), 2);
-			gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_sidebar), 1);
 		}
 	}
 
